@@ -6,7 +6,7 @@ use Moo;
 use Try::Tiny;
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.47';
+our $VERSION = '0.48';
 
 sub _build_cmd {'js-beautify'}
 
@@ -17,12 +17,13 @@ sub transform_file {
         my $cmd = join( " ", $self->cmd, $self->argv, $file );
 
         my $output;
-        run3( $cmd, \undef, \$output, \$output );
+        my $exit = run3( $cmd, \undef, \$output, \$output );
+        die "exited with $?\n" if $?;
         write_file( $file, $output );
     }
     catch {
         die sprintf(
-            "%s exited with error - possibly bad arg list '%s'\n    $_", $self->cmd,
+            "%s failed - possibly bad arg list '%s'\n    $_", $self->cmd,
             $self->argv
         );
     };
@@ -44,7 +45,7 @@ Code::TidyAll::Plugin::JSBeautify - Use js-beautify with tidyall
 
 =head1 VERSION
 
-version 0.47
+version 0.48
 
 =head1 SYNOPSIS
 
